@@ -439,8 +439,14 @@ enum
 #define CS_FMT_PADBLANK CS_FMT_PADBLANK
 	CS_FMT_PADBLANK = 4,
 #define CS_FMT_PADNULL CS_FMT_PADNULL
-	CS_FMT_JUSTIFY_RT = 8
+	CS_FMT_JUSTIFY_RT = 8,
 #define CS_FMT_JUSTIFY_RT CS_FMT_JUSTIFY_RT
+	CS_FMT_STRIPBLANKS = 16,
+#define CS_FMT_STRIPBLANKS CS_FMT_STRIPBLANKS
+	CS_FMT_SAFESTR = 32,
+#define CS_FMT_SAFESTR CS_FMT_SAFESTR
+	CS_FMT_SUBS_ILL_CHAR = 64
+#define CS_FMT_SUBS_ILL_CHAR CS_FMT_SUBS_ILL_CHAR
 };
 
 /* callbacks */
@@ -700,7 +706,35 @@ enum
 #define CS_DATES_MYD1 CS_DATES_MYD1
 	CS_DATES_DYM1,
 #define CS_DATES_DYM1 CS_DATES_DYM1
-	CS_DATES_MDY1_YYYY = 101,
+	CS_DATES_MDYHMS,
+#define CS_DATES_MDYHMS CS_DATES_MDYHMS
+	CS_DATES_HMA,
+#define CS_DATES_HMA CS_DATES_HMA
+	CS_DATES_HM,
+#define CS_DATES_HM CS_DATES_HM
+	CS_DATES_HMSZA,
+#define CS_DATES_HMSZA CS_DATES_HMSZA
+	CS_DATES_HMSZ,
+#define CS_DATES_HMSZ CS_DATES_HMSZ
+	CS_DATES_YMDHMS,
+#define CS_DATES_YMDHMS CS_DATES_YMDHMS
+	CS_DATES_YMDHMA,
+#define CS_DATES_YMDHMA CS_DATES_YMDHMA
+	CS_DATES_YMDTHMS,
+#define CS_DATES_YMDTHMS CS_DATES_YMDTHMS
+	CS_DATES_HMSUSA = 36,
+#define CS_DATES_HMSUSA CS_DATES_HMSUSA
+	CS_DATES_HMSUS,
+#define CS_DATES_HMSUS CS_DATES_HMSUS
+	CS_DATES_LONGUSA,
+#define CS_DATES_LONGUSA CS_DATES_LONGUSA
+	CS_DATES_LONGUS,
+#define CS_DATES_LONGUS CS_DATES_LONGUS
+	CS_DATES_YMDHMSUS,
+#define CS_DATES_YMDHMSUS CS_DATES_YMDHMSUS
+	CS_DATES_SHORT_ALT = 100,
+#define CS_DATES_SHORT_ALT CS_DATES_SHORT_ALT
+	CS_DATES_MDY1_YYYY,
 #define CS_DATES_MDY1_YYYY CS_DATES_MDY1_YYYY
 	CS_DATES_YMD1_YYYY,
 #define CS_DATES_YMD1_YYYY CS_DATES_YMD1_YYYY
@@ -714,12 +748,42 @@ enum
 #define CS_DATES_DMY4_YYYY CS_DATES_DMY4_YYYY
 	CS_DATES_MDY2_YYYY,
 #define CS_DATES_MDY2_YYYY CS_DATES_MDY2_YYYY
-	CS_DATES_MDY3_YYYY = 110,
+	CS_DATES_HMS_ALT,
+#define CS_DATES_HMS_ALT CS_DATES_HMS_ALT
+	CS_DATES_LONG_ALT,
+#define CS_DATES_LONG_ALT CS_DATES_LONG_ALT
+	CS_DATES_MDY3_YYYY,
 #define CS_DATES_MDY3_YYYY CS_DATES_MDY3_YYYY
 	CS_DATES_YMD2_YYYY,
 #define CS_DATES_YMD2_YYYY CS_DATES_YMD2_YYYY
-	CS_DATES_YMD3_YYYY
+	CS_DATES_YMD3_YYYY,
 #define CS_DATES_YMD3_YYYY CS_DATES_YMD3_YYYY
+	CS_DATES_YDM1_YYYY,
+#define CS_DATES_YDM1_YYYY CS_DATES_YDM1_YYYY
+	CS_DATES_MYD1_YYYY,
+#define CS_DATES_MYD1_YYYY CS_DATES_MYD1_YYYY
+	CS_DATES_DYM1_YYYY,
+#define CS_DATES_DYM1_YYYY CS_DATES_DYM1_YYYY
+	CS_DATES_MDYHMS_ALT,
+#define CS_DATES_MDYHMS_ALT CS_DATES_MDYHMS_ALT
+	CS_DATES_HMA_ALT,
+#define CS_DATES_HMA_ALT CS_DATES_HMA_ALT
+	CS_DATES_HM_ALT,
+#define CS_DATES_HM_ALT CS_DATES_HM_ALT
+	CS_DATES_YMDHMS_YYYY = 121,
+#define CS_DATES_YMDHMS_YYYY CS_DATES_YMDHMS_YYYY
+	CS_DATES_YMDHMA_YYYY,
+#define CS_DATES_YMDHMA_YYYY CS_DATES_YMDHMA_YYYY
+	CS_DATES_HMSUSA_YYYY = 136,
+#define CS_DATES_HMSUSA_YYYY CS_DATES_HMSUSA_YYYY
+	CS_DATES_HMSUS_YYYY,
+#define CS_DATES_HMSUS_YYYY CS_DATES_HMSUS_YYYY
+	CS_DATES_LONGUSA_YYYY,
+#define CS_DATES_LONGUSA_YYYY CS_DATES_LONGUSA_YYYY
+	CS_DATES_LONGUS_YYYY,
+#define CS_DATES_LONGUS_YYYY CS_DATES_LONGUS_YYYY
+	CS_DATES_YMDHMSUS_YYYY
+#define CS_DATES_YMDHMSUS_YYYY CS_DATES_YMDHMSUS_YYYY
 };
 
 typedef CS_RETCODE(*CS_CONV_FUNC) (CS_CONTEXT * context, CS_DATAFMT * srcfmt, CS_VOID * src, CS_DATAFMT * detsfmt, CS_VOID * dest,
