@@ -361,7 +361,7 @@ extern const char *const tds_type_names[256];
 #define is_variant_inner_type(x)   ((tds_type_flags_ms[x] & TDS_TYPEFLAG_VARIANT) != 0)
 
 
-#define is_blob_type(x)       ((x)==SYBTEXT || (x)==SYBIMAGE || (x)==SYBNTEXT)
+#define type_has_textptr(x)   ((x)==SYBTEXT || (x)==SYBIMAGE || (x)==SYBNTEXT)
 #define is_blob_col(x)        ((x)->column_varint_size > 2)
 /* large type means it has a two byte size field */
 /* define is_large_type(x) (x>128) */
@@ -684,16 +684,31 @@ struct tds_column
 	TDS_INT column_usertype;
 	TDS_INT column_flags;
 
-	TDS_INT column_size;		/**< maximun size of data. For fixed is the size. */
+	/**
+	 * Maximun size of data. For fixed types is the size.
+	 */
+	TDS_INT column_size;
 
-	TDS_SERVER_TYPE column_type;	/**< This type can be different from wire type because
-	 				 * conversion (e.g. UCS-2->Ascii) can be applied.
-					 * I'm beginning to wonder about the wisdom of this, however.
-					 * April 2003 jkl
-					 */
-	TDS_TINYINT column_varint_size;	/**< size of length when reading from wire (0, 1, 2 or 4) */
+	/**
+	 * This type can be different from wire type because
+	 * conversion (e.g. UCS-2->Ascii) can be applied.
+	 * I'm beginning to wonder about the wisdom of this, however.
+	 * April 2003 jkl
+	 */
+	TDS_SERVER_TYPE column_type;
 
-	TDS_TINYINT column_prec;	/**< precision for decimal/numeric */
+	/**
+	 * Size of length when reading from wire (0, 1, 2, 4, 5 or 8).
+	 * 0 means fixed type.
+	 * 1, 2 and 4 means the data stream contains a length exactly these bytes.
+	 * 5 means old BLOB types having TEXTPTR on them. 5 as they contain 2 lengths,
+	 * one 4 bytes for data length and another 1 byte for TEXTPTR length.
+	 * 8 are MSSQL VARBINARY/VARCHAR(MAX) which have a 8 byte length, although
+	 * data types are still limited to 2GB.
+	 */
+	TDS_TINYINT column_varint_size;
+
+	TDS_TINYINT column_prec;	/**< precision for decimal/numeric and some datetime types */
 	TDS_TINYINT column_scale;	/**< scale for decimal/numeric */
 
 	struct
@@ -1548,8 +1563,18 @@ void tdsdump_log_impl(const char* file, unsigned int level_line, const char *fmt
 #endif
 #endif
 ;
+#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
+/* If available use C99 and __VA_ARGS__ */
+#define tdsdump_log(...) do { \
+	if (TDS_UNLIKELY(tds_write_dump)) tdsdump_log_impl(__VA_ARGS__); \
+} while(0)
+#define tdsdump_dump_buf(...) do { \
+	if (TDS_UNLIKELY(tds_write_dump)) tdsdump_dump_buf_impl(__VA_ARGS__); \
+} while(0)
+#else
 #define tdsdump_log if (!TDS_UNLIKELY(tds_write_dump)) {} else tdsdump_log_impl
 #define tdsdump_dump_buf if (!TDS_UNLIKELY(tds_write_dump)) {} else tdsdump_dump_buf_impl
+#endif
 
 extern bool tds_write_dump;
 extern int tds_debug_flags;
@@ -1712,6 +1737,7 @@ struct tds_bcpinfo
 	TDSRESULTINFO *bindinfo;
 	TDS5COLINFO *sybase_colinfo;
 	TDS_INT sybase_count;
+	bool with_triggers;
 };
 
 TDSRET tds_bcp_init(TDSSOCKET *tds, TDSBCPINFO *bcpinfo);
